###	PREPARING DATA
library(R2WinBUGS)
library(ggplot2)
setwd("C:\\") #please set wd as required

#
#	computing inputs via Guyot-Ouwens algorithm
#
	source("Source_data_2_pivotal_trials\\cabonivo_newinputs.R")
	ns_convert <- function(inp, t, b, s) {
		inp$time <- c(inp[-1,"V1"], 1000)
		inp$dt <- inp$time - c(0, inp[-nrow(inp),"time"])
		inp$n <- inp$V2
		inp$r <- inp$V3
		inp$t <- t
		inp$b <- b
		inp$s <- s
		return(inp[-nrow(inp),c("time", "dt", "n", "r", "t", "b", "s")])

		}
	winbugsi_new <- rbind(ns_convert(os1_cabo$curve, 2, 1, 1), ns_convert(os1_ev$curve, 1, 1, 1), ns_convert(os2_nivo$curve, 3, 1, 2), ns_convert(os2_ev$curve, 1, 1, 2))
	winbugsi <- winbugsi_new[winbugsi_new$n > 0,]



###models via R2WinBUGS:
	#inputs:
	bugs_input <- list(
		"N"=nrow(winbugsi), "NS"=2, "NT"=3, "mean"=c(0,0), "prec2"=matrix(c(.0001,0,0,.0001),2,2), "R"=matrix(c(.01,0,0,.01),2,2), #.0001 worked ok, but with slow convergence
		"time"=winbugsi[,1], "dt"=winbugsi[,2], "n"=winbugsi[,3], "r"=winbugsi[,4], "t"=winbugsi[,5], "b"=winbugsi[,6], "s"=winbugsi[,7], 
		"ts"=c(2,3), "bs"=c(1,1)
		)
	bugs_input_fixed <- bugs_input
	bugs_input_fixed$R <- NULL

	bugs_inits <- list(
		list("mu"=matrix(-c(1,1,.1,.1),2,2), 		"d"=matrix(c(NA, 2, -2,NA,.1, -.1),3,2)), 
		list("mu"=matrix(-c(1,1,.1,.1),2,2), 		"d"=matrix(c(NA,-2, 2,NA, -.1, .1),3,2)), 
		list("mu"=matrix( c(-1,-1,-.1,-.1),2,2), 	"d"=matrix(c(NA, 2, 2,NA, .1, .1 ),3,2)),
		list("mu"=matrix(-c(-1,-1,-.1,-.1),2,2), 	"d"=matrix(c(NA,-2,-2,NA,-.1,-.1 ),3,2))
	)


	#weibull
	ww.weib.fixed <- bugs(data = bugs_input_fixed, inits=bugs_inits, "BUGS run", model.file="bugs_model_Weibull.txt", bugs.directory="C:/WinBUGS14", parameters=c("mu", "d"), n.chains=4, n.iter=50000, n.burnin=25000, n.thin=10)

	# gompertz
	ww.gompertz.fixed <- bugs(data = bugs_input_fixed, inits=bugs_inits, "BUGS run", model.file="bugs_model_Gompertz.txt", bugs.directory="C:/WinBUGS14", parameters=c("mu", "d"), n.chains=4, n.iter=50000, n.burnin=25000, n.thin=10)

	# loglog = alright
	ww.log.fixed <- bugs(data = bugs_input_fixed, inits=bugs_inits, "BUGS run", model.file="bugs_model_loglogistic.txt", bugs.directory="C:/WinBUGS14", parameters=c("mu", "d"), n.chains=4, n.iter=50000, n.burnin=25000, n.thin=10, debug=FALSE)

	#exponential: needs other starting values to not crash WinBUGS
	bugs_inits_exp_fixed <- list(
		list("mu"=c(0.5,0.5), "d"=c(NA, .1,.1)),
		list("mu"=c(0.5,0.5), "d"=c(NA, .1,-.1)),
		list("mu"=c(0.5,0.5), "d"=c(NA, .1,.1)),
		list("mu"=c(0.5,0.5), "d"=c(NA, -.1,.1))
	)
	bugs_input_exp <- bugs_input_fixed
	bugs_input_exp$time <- NULL
	bugs_input_exp$prec2 <- NULL
	bugs_input_exp$omega <- NULL
	bugs_input_exp$mean  <- NULL
	ww.exp.fixed <- bugs(data = bugs_input_exp, inits=bugs_inits_exp_fixed, "BUGS run", model.file="bugs_model_exp_fixed.txt", bugs.directory="C:/WinBUGS14", parameters=c("mu", "d"), n.chains=4, n.iter=50000, n.burnin=25000, n.thin=10, debug=FALSE)

###COMPUTING RESULTS:

###now we can sample from posterior; names for chain matrices:
	xsim <- seq(0,24, length=500)
	sm <- ww.weib.fixed$sims.matrix
	sm.gomp <- ww.gompertz.fixed$sims.matrix
	sm.log <- ww.log.fixed$sims.matrix
	sm.exp <- ww.exp.fixed$sims.matrix

###hazard functions for all distributions:
	hf.weib <- function(xsim, sm) {
			sim1 <- apply(sm, 1, function(y) exp(y[1]+(log(xsim)*y[2])))
			mci <- t(apply(sim1, 1, function(x) quantile(x, c(.025,.05,.25,.5,.75,.95,.975), na.rm=T)))
			colnames(mci) <- c("l025", "l05", "l25", "med", "u75", "u95", "u975")
			return(mci)
	}

	hf.gomp <- function(xsim, sm) {
			sim1 <- apply(sm, 1, function(y) exp(y[1]+(xsim*y[2])))
			mci <- t(apply(sim1, 1, function(x) quantile(x, c(.025,.05,.25,.5,.75,.95,.975), na.rm=T)))
			colnames(mci) <- c("l025", "l05", "l25", "med", "u75", "u95", "u975")
			return(mci)
	}

	hf.log <- function(xsim, sm) {
			sim1 <- apply(sm, 1, function(y) ((exp(y[2])/exp(y[1]))*((xsim/exp(y[1]))^(exp(y[2])-1)))/(1+((xsim/exp(y[1]))^exp(y[2]))))
			mci <- t(apply(sim1, 1, function(x) quantile(x, c(.025,.05,.25,.5,.75,.95,.975), na.rm=T)))
			colnames(mci) <- c("l025", "l05", "l25", "med", "u75", "u95", "u975")
			return(mci)
			}

	hf.exp  <- function(xsim, sm) { #version with exp transform of both parameters
			sm <- data.frame(sm)
			sim1 <- apply(sm, 1, function(y) rep(y[1], length(xsim)))
			mci <- t(apply(sim1, 1, function(x) quantile(x, c(.025,.05,.25,.5,.75,.95,.975), na.rm=T)))
			colnames(mci) <- c("l025", "l05", "l25", "med", "u75", "u95", "u975")
			return(mci)
	}

#compute survival curve parameters + CIs
	gomp.ribbon <- function(xsim, sm) {
		sim1 <- apply(sm, 1, function(y) exp((-exp(y[1])/y[2])*(exp(xsim*y[2]) - 1)))
		mci <- t(apply(sim1, 1, function(x) quantile(x, c(.025,.05,.25,.5,.75,.95,.975), na.rm=T)))
		colnames(mci) <- c("l025", "l05", "l25", "med", "u75", "u95", "u975")
		return(mci)
	}
	
	weib.ribbon <- function(xsim, sm) {
		sim1 <- apply(sm, 1, function(y) exp(-((xsim^(y[2]+1))*exp(y[1])/(y[2]+1))))
		mci <- t(apply(sim1, 1, function(x) quantile(x, c(.025,.05,.25,.5,.75,.95,.975), na.rm=T)))
		colnames(mci) <- c("l025", "l05", "l25", "med", "u75", "u95", "u975")
		return(mci)
	}
	
	log.ribbon <- function(xsim, sm) {
		sim1 <- apply(sm, 1, function(y) 1/(1+((xsim/exp(y[1]))^exp(y[2]))))
		mci <- t(apply(sim1, 1, function(x) quantile(x, c(.025,.05,.25,.5,.75,.95,.975), na.rm=T)))
		colnames(mci) <- c("l025", "l05", "l25", "med", "u75", "u95", "u975")
		return(mci)
	}
	
	exp.ribbon <- function(xsim, sm) {
		sm <- data.frame(sm)
		sim1 <- apply(sm, 1, function(y) exp(-xsim*y))
		mci <- t(apply(sim1, 1, function(x) quantile(x, c(.025,.05,.25,.5,.75,.95,.975), na.rm=T)))
		colnames(mci) <- c("l025", "l05", "l25", "med", "u75", "u95", "u975")
		return(mci)
	}
	

###by choosing columns of sm matrix we change baseline / effect definitions
	###weibull
	gr1 <- weib.ribbon(xsim, sm[,1:2]) #everolimus 1
	gr2 <- weib.ribbon(xsim, sm[,1:2]+sm[,c(5,6)]) #cabo 1
	gr2.adjusted <- weib.ribbon(xsim, sm[,3:4]+sm[,c(5,6)]) # cabo adjusted to study 2
	gr3 <- weib.ribbon(xsim, sm[,3:4]) #etc.
	gr4 <- weib.ribbon(xsim, sm[,3:4]+sm[,c(7,8)])
	gr4.adjusted <- weib.ribbon(xsim, sm[,1:2]+sm[,c(7,8)])
	###gomp
	grgomp1 <- gomp.ribbon(xsim, sm.gomp[,1:2])
	grgomp2 <- gomp.ribbon(xsim, sm.gomp[,1:2]+sm.gomp[,5:6])
	grgomp2.adjusted <- gomp.ribbon(xsim, sm.gomp[,3:4]+sm.gomp[,5:6])
	grgomp3 <- gomp.ribbon(xsim, sm.gomp[,3:4])
	grgomp4 <- gomp.ribbon(xsim, sm.gomp[,3:4]+sm.gomp[,7:8])
	grgomp4.adjusted <- gomp.ribbon(xsim, sm.gomp[,1:2]+sm.gomp[,7:8])
	#log-logistic:
	grlog1 <- log.ribbon(xsim, sm.log[,1:2])
	grlog2 <- log.ribbon(xsim, sm.log[,1:2]+sm.log[,c(5,6)])
	grlog2.adjusted <- log.ribbon(xsim, sm.log[,3:4]+sm.log[,c(5,6)])
	grlog3 <- log.ribbon(xsim, sm.log[,3:4])
	grlog4 <- log.ribbon(xsim, sm.log[,3:4]+sm.log[,c(7,8)])
	grlog4.adjusted <- log.ribbon(xsim, sm.log[,1:2]+sm.log[,c(7,8)])
	###exp
	grexp1 <- exp.ribbon(xsim, sm.exp[,1])
	grexp2 <- exp.ribbon(xsim, sm.exp[,1]+sm.exp[,3])
	grexp2.adjusted <- exp.ribbon(xsim, sm.exp[,2]+sm.exp[,3])
	grexp3 <- exp.ribbon(xsim, sm.exp[,2])
	grexp4 <- exp.ribbon(xsim, sm.exp[,2]+sm.exp[,4])
	grexp4.adjusted <- exp.ribbon(xsim, sm.exp[,1]+sm.exp[,4])


	#ggplot inputs 
	ggdata <- rbind(
		data.frame(grlog1, "fit"="log-logistic", "curve"="everolimus (Choueiri et al)", "study"="Choueiri et al", xsim),
		data.frame(grlog2, "fit"="log-logistic", "curve"="cabozantinib (Choueiri et al)", "study"="Choueiri et al", xsim),
		data.frame(grlog3, "fit"="log-logistic", "curve"="everolimus (Motzer et al)", "study"="Motzer et al", xsim),
		data.frame(grlog4, "fit"="log-logistic", "curve"="nivolumab (Motzer et al)", "study"="Motzer et al", xsim),
		data.frame(gr1, "fit"="Weibull", "curve"="everolimus (Choueiri et al)", "study"="Choueiri et al", xsim),
		data.frame(gr2, "fit"="Weibull", "curve"="cabozantinib (Choueiri et al)", "study"="Choueiri et al", xsim),
		data.frame(gr3, "fit"="Weibull", "curve"="everolimus (Motzer et al)", "study"="Motzer et al", xsim),
		data.frame(gr4, "fit"="Weibull", "curve"="nivolumab (Motzer et al)", "study"="Motzer et al", xsim),
		data.frame(grgomp1, "fit"="Gompertz", "curve"="everolimus (Choueiri et al)", "study"="Choueiri et al", xsim),
		data.frame(grgomp2, "fit"="Gompertz", "curve"="cabozantinib (Choueiri et al)", "study"="Choueiri et al", xsim),
		data.frame(grgomp3, "fit"="Gompertz", "curve"="everolimus (Motzer et al)", "study"="Motzer et al", xsim),
		data.frame(grgomp4, "fit"="Gompertz", "curve"="nivolumab (Motzer et al)", "study"="Motzer et al", xsim),
		data.frame(grexp1, "fit"="Exponential", "curve"="everolimus (Choueiri et al)", "study"="Choueiri et al", xsim),
		data.frame(grexp2, "fit"="Exponential", "curve"="cabozantinib (Choueiri et al)", "study"="Choueiri et al", xsim),
		data.frame(grexp3, "fit"="Exponential", "curve"="everolimus (Motzer et al)", "study"="Motzer et al", xsim),
		data.frame(grexp4, "fit"="Exponential", "curve"="nivolumab (Motzer et al)", "study"="Motzer et al", xsim)
		)
	
	point1 <- read.table("2016 02 new source\\inputs\\os1_cabozantinib_survival.csv", sep=",", header=TRUE)[,2:3]
	point2 <- read.table("2016 02 new source\\inputs\\os1_everolimus_survival.csv", sep=",", header=TRUE)[,2:3]
	point3 <- read.table("2016 02 new source\\inputs\\os2_nivolumab_survival.csv", sep=",", header=TRUE)[,2:3]
	point4 <- read.table("2016 02 new source\\inputs\\os2_everolimus_survival.csv", sep=",", header=TRUE)[,2:3]
	
	ggpoint <- rbind(
		data.frame("time"=point1[,1], "prop"=point1[,2],	"original"="cabozantinib (Choueiri et al)", "study"="Choueiri et al"),
		data.frame("time"=point2[,1], "prop"=point2[,2], 	"original"="everolimus (Choueiri et al)", "study"="Choueiri et al"),
		data.frame("time"=point3[,1], "prop"=point3[,2],	"original"="nivolumab (Motzer et al)", "study"="Motzer et al"),
		data.frame("time"=point4[,1], "prop"=point4[,2],	"original"="everolimus (Motzer et al)", "study"="Motzer et al")
		)

	
#compute HR:
	xhr <- seq(1, 24, .25)
		
	weib.hr <- function(xhr, sm) {
		hr1 <- apply(sm, 1, function(x) exp(x[1] + x[2]*log(xhr)))
		hrmed <- t(apply(hr1, 1, function(x) c(quantile(x, c(.025, .25, .5, .75, .975), na.rm=T), mean(x))))
		return(data.frame("x"=xhr, hrmed))
		}
	gomp.hr <- function(xhr, sm) {
		hr1 <- apply(sm, 1, function(x) exp(x[1] + x[2]*xhr))
		hrmed <- t(apply(hr1, 1, function(x) c(quantile(x, c(.025, .25, .5, .75, .975), na.rm=T), mean(x))))
		return(data.frame("x"=xhr, hrmed))
		}
	exp.hr <- function(xhr, sm1, sm2) {
		sm <- data.frame(sm1, sm2)
		hr1 <- apply(sm, 1, function(x) rep(x[1]/x[2], length(xhr)))
		hrmed <- t(apply(hr1, 1, function(x) c(quantile(x, c(.025, .25, .5, .75, .975), na.rm=T), mean(x))))
		return(data.frame("x"=xhr, hrmed))
	}
	#for log-logistic we don't use a formula & just derive it from hazard functions:
	log.hr <- function(xhr, sm1, sm2) {
		sm <- data.frame(sm1, sm2)
		hr1 <- apply(sm, 1, function(y) {
				(((exp(y[4])/exp(y[3]))*((xhr/exp(y[3]))^(exp(y[4])-1)))/(1+((xhr/exp(y[3]))^exp(y[4])))) 	/   (((exp(y[2])/exp(y[1]))*((xhr/exp(y[1]))^(exp(y[2])-1)))/(1+((xhr/exp(y[1]))^exp(y[2])))) #!!!
			})
		hrmed <- t(apply(hr1, 1, function(x) c(quantile(x, c(.025, .25, .5, .75, .975), na.rm=T), mean(x))))
		return(data.frame("x"=xhr, hrmed))
	}
	

	#data for ggplot:
	gghr <- rbind(
		data.frame(log.hr(xhr, sm.log[,1:2], sm.log[,1:2] + sm.log[,5:6]), 				"HR"="cabozantinib vs everolimus", 			"fit"="log-logistic", 	"comparison"="direct comparison"),
		data.frame(log.hr(xhr, sm.log[,3:4], sm.log[,3:4] + sm.log[,7:8]), 				"HR"="nivolumab vs everolimus", 				"fit"="log-logistic", 	"comparison"="direct comparison"),
		data.frame(log.hr(xhr, sm.log[,1:2] + sm.log[,5:6], sm.log[,3:4] + sm.log[,7:8]), "HR"="nivolumab vs cabozantinib", 			"fit"="log-logistic", 	"comparison"="indirect comparison"),
		
		data.frame(weib.hr(xhr, sm[,5:6]), "HR"="cabozantinib vs everolimus", 			"fit"="Weibull", 	"comparison"="direct comparison"),
		data.frame(weib.hr(xhr, sm[,7:8]), "HR"="nivolumab vs everolimus", 				"fit"="Weibull", 	"comparison"="direct comparison"),
		data.frame(weib.hr(xhr, sm[,7:8] - sm[,5:6]), "HR"="nivolumab vs cabozantinib", 	"fit"="Weibull", 	"comparison"="indirect comparison"),
		
		data.frame(gomp.hr(xhr, sm.gomp[,5:6]), 				"HR"="cabozantinib vs everolimus", 			"fit"="Gompertz", 	"comparison"="direct comparison"),
		data.frame(gomp.hr(xhr, sm.gomp[,7:8]), 				"HR"="nivolumab vs everolimus", 				"fit"="Gompertz", 	"comparison"="direct comparison"),
		data.frame(gomp.hr(xhr, sm.gomp[,7:8] - sm.gomp[,5:6]), "HR"="nivolumab vs cabozantinib", 			"fit"="Gompertz", 	"comparison"="indirect comparison"),
				
		data.frame(exp.hr(xhr, sm.exp[,1] + sm.exp[,3], sm.exp[,1]), 				"HR"="cabozantinib vs everolimus", "fit"="Exponential", 	"comparison"="direct comparison"),
		data.frame(exp.hr(xhr, sm.exp[,2] + sm.exp[,4], sm.exp[,2]), 				"HR"="nivolumab vs everolimus", 		"fit"="Exponential", "comparison"="direct comparison"),
		data.frame(exp.hr(xhr, sm.exp[,2] + sm.exp[,4], sm.exp[,1] + sm.exp[,3]), 	"HR"="nivolumab vs cabozantinib",  "fit"="Exponential", 	"comparison"="indirect comparison")
	)
	colnames(gghr) <- c("x", "lci", "lci50", "med", "uci50", "uci", "mean", "HR", "fit", "comparison")


	
	
###PLOTTING - results output
# library(Cairo)
cbPalette <- c("#999999", "#E69F00", "#56B4E9", "#009E73",  "#F0E442", "#0072B2", "#D55E00", "#CC79A7", "#7F7F7F")[c(2,4,3,7,8,5, 9)] #color-blind palette

	#ggplot of data (no adjustments, facetted)
		tt1 <- ggplot(ggdata, aes(x=xsim)) + geom_line(aes(y=med, group=curve, colour=curve), size=1.5) +
		scale_colour_manual(values=cbPalette) + 
		facet_grid(study ~ fit) + 
		geom_ribbon(aes(ymax=u975, ymin=l025, group=curve, fill=curve), alpha=.1) + 
		geom_ribbon(aes(ymax=u75, ymin=l25, group=curve, fill=curve), alpha=.2) + 
		scale_fill_manual(values=cbPalette) + 
		xlab("Months") + ylab("Overall survival") +
		# geom_point(data=ggpoint, aes(x=time, y=prop, group=original, color=original, shape=original), size=3) +
		ggtitle("Fitted survival curves from both studies (no adjustment)") +
		xlim(c(0,30)) + ylim(c(0,1)) + scale_x_continuous(breaks=c(0,6,12,18,24)) + theme_bw(base_size=16)
		# ggsave("outputs\\ggtest1.jpg", tt1, width=12, height=9, dpi=300, quality=90)

	#ggplot of adjusted data: to study 1:
		ggdata.adjusted <- rbind(
			data.frame(grlog1, "curve"="everolimus (Choueiri et al)", "study"="Choueiri et al", xsim),
			data.frame(grlog2, "curve"="cabozantinib (Choueiri et al)", "study"="Choueiri et al", xsim),
			data.frame(grlog4.adjusted, "curve"="nivolumab (adjusted)	", "study"="Motzer et al", xsim))
		tt2 <- ggplot(ggdata.adjusted, aes(x=xsim)) + geom_line(aes(y=med, group=curve, colour=curve), size=1.5) +
			scale_colour_manual(values=cbPalette[c(1,2,4)]) + 
			geom_ribbon(aes(ymax=u975, ymin=l025, group=curve, fill=curve), alpha=.1) + 
			geom_ribbon(aes(ymax=u75, ymin=l25, group=curve, fill=curve), alpha=.2) + 
			scale_fill_manual(values=cbPalette[c(1,2,4)]) + 
			xlab("Months") + ylab("Overall survival") +
			# geom_point(data=ggpoint, aes(x=time, y=prop, group=curve, color=curve, shape=curve), size=3) +
			ggtitle("Survival curves adjusted to baseline from Choueiri study") +
			xlim(c(0,30)) + ylim(c(0,1)) + scale_x_continuous(breaks=c(0,6,12,18,24)) + theme_bw(base_size=16)
		# ggsave("outputs\\ggtest2.jpg", tt2, width=12, height=9, dpi=300, quality=90)

	#ggplot of adjusted data: to study 2:
		ggdata.adjusted2 <- rbind(
			data.frame(grlog2.adjusted, "curve"="cabozantinib (adjusted)", "study"="Choueiri et al", xsim),
			data.frame(grlog3, "curve"="everolimus (Motzer et al)", "study"="Motzer et al", xsim),
			data.frame(grlog4, "curve"="nivolumab (Motzer et al)", "study"="Motzer et al", xsim))
		tt3 <- ggplot(ggdata.adjusted2, aes(x=xsim)) + geom_line(aes(y=med, group=curve, colour=curve), size=1.5) +
			scale_colour_manual(values=cbPalette[c(1,3,4)]) + 
			geom_ribbon(aes(ymax=u975, ymin=l025, group=curve, fill=curve), alpha=.1) + 
			geom_ribbon(aes(ymax=u75, ymin=l25, group=curve, fill=curve), alpha=.2) +
			scale_fill_manual(values=cbPalette[c(1,3,4)]) + 			
			xlab("Months") + ylab("Overall survival") +
			# geom_point(data=ggpoint, aes(x=time, y=prop, group=curve, color=curve, shape=curve), size=3) +
			ggtitle("Survival curves adjusted to baseline from Motzer study") +
			xlim(c(0,30)) + ylim(c(0,1)) + scale_x_continuous(breaks=c(0,6,12,18,24)) + theme_bw(base_size=16)
		# ggsave("outputs\\ggtest3.jpg", tt3, width=12, height=9, dpi=300, quality=90)
		

	#updated to grayscale:
		tt3 <- ggplot(ggdata.adjusted2[seq(0,1500,length=100),], aes(x=xsim)) + 
			# geom_line(aes(y=med, group=curve, colour=curve), size=1.5) +
			geom_point(aes(y=med, group=curve, shape=curve), size=1.5) +
			geom_point(aes(y=u975, group=curve, shape=curve), size=1.5) +
			geom_point(aes(y=l025, group=curve, shape=curve), size=1.5) +
			scale_colour_grey() + 
			# geom_ribbon(aes(ymax=u975, ymin=l025, group=curve, fill=curve), alpha=.05) + 
			# geom_ribbon(aes(ymax=u75, ymin=l25, group=curve, fill=curve), alpha=.2) +
			scale_fill_grey() + 			
			xlab("Months") + ylab("Overall survival") +
			# geom_point(data=ggpoint, aes(x=time, y=prop, group=curve, color=curve, shape=curve), size=3) +
			ggtitle("Survival curves adjusted to baseline from Motzer study") +
			xlim(c(0,30)) + ylim(c(0,1)) + scale_x_continuous(breaks=c(0,6,12,18,24)) + theme_bw(base_size=16)
		# ggsave("outputs\\ggtest3.jpg", tt3, width=12, height=9, dpi=300, quality=90)

	#ggplot of adjusted data: to study 2:
		ggdata.adjusted2 <- rbind(
			data.frame(grlog2.adjusted, "curve"="cabozantinib (adjusted to Motzer et al)", "study"="Choueiri et al", xsim),
			data.frame(grlog4, "curve"="nivolumab (Motzer et al)", "study"="Motzer et al", xsim),
			data.frame(grlog3, "curve"="everolimus (Motzer et al)", "study"="Motzer et al", xsim))
		levels(ggdata.adjusted2$curve) <- c("cabozantinib", "nivolumab", "everolimus")
		tt3 <- ggplot(ggdata.adjusted2, aes(x=xsim)) + geom_line(aes(y=med, group=curve, colour=curve), size=1.5) +
			scale_colour_manual(values=cbPalette[c(4,3,7)]) + 
			geom_ribbon(aes(ymax=u975, ymin=l025, group=curve, fill=curve), alpha=.3) + 
			# geom_ribbon(aes(ymax=u75, ymin=l25, group=curve, fill=curve), alpha=.2) +
			scale_fill_manual(values=cbPalette[c(4,3,7)]) + 			
			xlab("time (months)") + ylab("overall survival") +
			# geom_point(data=ggpoint, aes(x=time, y=prop, group=curve, color=curve, shape=curve), size=3) +
			xlim(c(0,30)) + ylim(c(0,1)) + scale_x_continuous(breaks=c(0,6,12,18,24)) + theme_bw(base_size=20) + theme(legend.title=element_blank()) + 		theme(legend.justification=c(0,0), legend.position=c(0,0))
		# ggsave("outputs\\ggtest3.jpg", tt3, width=12, height=9, dpi=300, quality=90)
	
	#ggplot of adjusted data: to study 2 - all families of distributions
		ggdata.adjusted_big <- rbind(
			data.frame(grlog2.adjusted, "curve"="cabozantinib (adjusted to Motzer et al)", "study"="Choueiri et al", xsim, "fit"="log-logistic"),
			data.frame(grlog4, "curve"="nivolumab (Motzer et al)", "study"="Motzer et al", xsim, "fit"="log-logistic"),
			data.frame(grlog3, "curve"="everolimus (Motzer et al)", "study"="Motzer et al", xsim, "fit"="log-logistic"),
			data.frame(gr2.adjusted, "curve"="cabozantinib (adjusted to Motzer et al)", "study"="Choueiri et al", xsim, "fit"="Weibull"),
			data.frame(gr4, "curve"="nivolumab (Motzer et al)", "study"="Motzer et al", xsim, "fit"="Weibull"),
			data.frame(gr3, "curve"="everolimus (Motzer et al)", "study"="Motzer et al", xsim, "fit"="Weibull"),
			data.frame(grgomp2.adjusted, "curve"="cabozantinib (adjusted to Motzer et al)", "study"="Choueiri et al", xsim, "fit"="Gompertz"),
			data.frame(grgomp4, "curve"="nivolumab (Motzer et al)", "study"="Motzer et al", xsim, "fit"="Gompertz"),
			data.frame(grgomp3, "curve"="everolimus (Motzer et al)", "study"="Motzer et al", xsim, "fit"="Gompertz"),
			data.frame(grexp2.adjusted, "curve"="cabozantinib (adjusted to Motzer et al)", "study"="Choueiri et al", xsim, "fit"="exponential"),
			data.frame(grexp4, "curve"="nivolumab (Motzer et al)", "study"="Motzer et al", xsim, "fit"="exponential"),
			data.frame(grexp3, "curve"="everolimus (Motzer et al)", "study"="Motzer et al", xsim, "fit"="exponential")
			)
		levels(ggdata.adjusted_big$curve) <- c("cabozantinib", "nivolumab", "everolimus")
		tt3 <- ggplot(ggdata.adjusted_big, aes(x=xsim)) + geom_line(aes(y=med, group=curve, colour=curve), size=1.5) +
			scale_colour_manual(values=cbPalette[c(4,3,7)]) + 
			facet_grid(.~fit) + 
			geom_ribbon(aes(ymax=u975, ymin=l025, group=curve, fill=curve), alpha=.3) + 
			scale_fill_manual(values=cbPalette[c(4,3,7)])  + 			
			xlab("time (months)") + ylab("overall survival") +
			xlim(c(0,30)) + ylim(c(0,1)) + scale_x_continuous(breaks=c(0,6,12,18,24)) + theme_bw(base_size=20) + theme(legend.title=element_blank()) + theme(legend.justification=c(0,0), legend.position=c(0,0))
		
	#plot HR:
		gghr$uci[gghr$uci > 3] <- 3
		tt4 <- ggplot(data=gghr) + geom_line(aes(x=x, y=med, color=HR, group=HR), size=1.5) +
		scale_colour_manual(values=cbPalette[c(5,3,2)]) + 
		facet_grid(comparison ~ fit) + 
		geom_ribbon(aes(x=x, ymax=uci, ymin=lci, fill=HR), alpha=.2) + 
		geom_ribbon(aes(x=x, ymax=uci50, ymin=lci50, fill=HR), alpha=.5) + 
		scale_fill_manual(values=cbPalette[c(5,3,2)]) + 
		xlab("time (months)") + ylab("HR(t)") + ggtitle("Network hazard ratios") +
		xlim(c(3,24)) + ylim(c(0,3)) + scale_x_continuous(breaks=c(6,12,18,24)) + theme_bw(base_size=16) + theme(legend.position="top")
		
		# ggsave("outputs\\ggtest4.jpg", tt4, width=12, height=9, dpi=300, quality=90)
	
#plot HR (updated, grayscale):
		gghr$uci[gghr$uci > 3] <- 3
		tt4 <- ggplot(data=gghr) + geom_line(aes(x=x, y=med), size=1.5) +
		scale_color_grey() + 
		facet_grid(HR ~ fit) + 
		geom_ribbon(aes(x=x, ymax=uci, ymin=lci), alpha=.2) + 
		geom_ribbon(aes(x=x, ymax=uci50, ymin=lci50), alpha=.5) + 
		scale_fill_grey() + 
		xlab("time (months)") + ylab("HR(t)") +
		xlim(c(3,24)) + ylim(c(0,3)) + scale_x_continuous(breaks=c(6,12,18,24)) + theme_bw(base_size=20) + theme(legend.position="top")
		
		# ggsave("outputs\\ggtest4.jpg", tt4, width=12, height=9, dpi=300, quality=90)

	
#tabularized results (every 3 months):
	ac <- gghr[gghr$x %in% c(3,6,9,12,15,18,21,24) & gghr$HR=="nivolumab vs cabozantinib", !(colnames(gghr) %in% c("lci50", "uci50", "comparison"))]
	library(reshape2)
	ac$cis <- paste0(round(ac$mean,2), " (", round(ac$lci,2), ", ", round(ac$uci,2), ")")
	data.frame(acast(ac, x~fit, value.var="cis"))

	
	
### PR(BEST TREATMENT)
	
#probability of being the best: log-logistic
	log.ribbon.best <- function(xsim, sm1, sm2, sm3) {
		sim1 <- apply(sm1, 1, function(y) 1/(1+((xsim/exp(y[1]))^exp(y[2]))))
		sim2 <- apply(sm2, 1, function(y) 1/(1+((xsim/exp(y[1]))^exp(y[2]))))
		sim3 <- apply(sm3, 1, function(y) 1/(1+((xsim/exp(y[1]))^exp(y[2]))))
		best1 <- apply(sim1 > sim2 & sim1 > sim3, 1, function(x) sum(x)/4000)
		best2 <- apply(sim2 > sim1 & sim2 > sim3, 1, function(x) sum(x)/4000)
		best3 <- apply(sim3 > sim2 & sim3 > sim1, 1, function(x) sum(x)/4000)
		return(list(best1, best2, best3))
	}
	bestlog1 <- log.ribbon.best(xsim, sm.log[,1:2]+sm.log[,c(5,6)], sm.log[,1:2]+sm.log[,c(7,8)], sm.log[,1:2])
	bestlog2 <- log.ribbon.best(xsim, sm.log[,3:4]+sm.log[,c(5,6)], sm.log[,3:4]+sm.log[,c(7,8)], sm.log[,3:4])
	
#probability of being the best: Weibull
	weib.ribbon.best <- function(xsim, sm1, sm2, sm3) {
		sim1 <- apply(sm1, 1, function(y) exp(-((xsim^(y[2]+1))*exp(y[1])/(y[2]+1))))
		sim2 <- apply(sm2, 1, function(y) exp(-((xsim^(y[2]+1))*exp(y[1])/(y[2]+1))))
		sim3 <- apply(sm3, 1, function(y) exp(-((xsim^(y[2]+1))*exp(y[1])/(y[2]+1))))
		best1 <- apply((sim1 > sim2) & (sim1 > sim3), 1, function(x) sum(x)/4000)
		best2 <- apply((sim2 > sim1) & (sim2 > sim3), 1, function(x) sum(x)/4000)
		best3 <- apply((sim3 > sim2) & (sim3 > sim1), 1, function(x) sum(x)/4000)
		return(list(best1, best2, best3))
	}
	bestweib1 <- weib.ribbon.best(xsim, sm[,1:2]+sm[,c(5,6)], sm[,1:2]+sm[,c(7,8)], sm[,1:2])
	bestweib2 <- weib.ribbon.best(xsim, sm[,3:4]+sm[,c(5,6)], sm[,3:4]+sm[,c(7,8)], sm[,3:4])
	
#probability of being the best: Gompertz
	gomp.ribbon.best <- function(xsim, sm1, sm2, sm3) {
		sim1 <- apply(sm1, 1, function(y) exp((-exp(y[1])/y[2])*(exp(xsim*y[2]) - 1)))
		sim2 <- apply(sm2, 1, function(y) exp((-exp(y[1])/y[2])*(exp(xsim*y[2]) - 1)))
		sim3 <- apply(sm3, 1, function(y) exp((-exp(y[1])/y[2])*(exp(xsim*y[2]) - 1)))
		best1 <- apply((sim1 > sim2) & (sim1 > sim3), 1, function(x) sum(x)/4000)
		best2 <- apply((sim2 > sim1) & (sim2 > sim3), 1, function(x) sum(x)/4000)
		best3 <- apply((sim3 > sim2) & (sim3 > sim1), 1, function(x) sum(x)/4000)
		return(list(best1, best2, best3))
	}
	bestgomp1 <- gomp.ribbon.best(xsim, sm.gomp[,1:2]+sm.gomp[,c(5,6)], sm.gomp[,1:2]+sm.gomp[,c(7,8)], sm.gomp[,1:2])
	bestgomp2 <- gomp.ribbon.best(xsim, sm.gomp[,3:4]+sm.gomp[,c(5,6)], sm.gomp[,3:4]+sm.gomp[,c(7,8)], sm.gomp[,3:4])
	
#probability of being the best: exp
	exp.ribbon.best <- function(xsim, sm1, sm2, sm3) {
		sim1 <- apply(data.frame(sm1), 1, function(y) exp(-xsim*y))
		sim2 <- apply(data.frame(sm2), 1, function(y) exp(-xsim*y))
		sim3 <- apply(data.frame(sm3), 1, function(y) exp(-xsim*y))
		best1 <- apply((sim1 > sim2) & (sim1 > sim3), 1, function(x) sum(x)/4000)
		best2 <- apply((sim2 > sim1) & (sim2 > sim3), 1, function(x) sum(x)/4000)
		best3 <- apply((sim3 > sim2) & (sim3 > sim1), 1, function(x) sum(x)/4000)
		return(list(best1, best2, best3))
	}
	bestexp1 <- exp.ribbon.best(xsim, sm.exp[,1]+sm.exp[,3], sm.exp[,1]+sm.exp[,4], sm.exp[,1])
	bestexp2 <- exp.ribbon.best(xsim, sm.exp[,2]+sm.exp[,3], sm.exp[,2]+sm.exp[,4], sm.exp[,2])
	
ggbest <- rbind(
	data.frame("x"=xsim[-1], "y"=bestlog1[[1]][-1], "treatment"="cabozantinib", "fit"="log-logistic"),
	data.frame("x"=xsim[-1], "y"=bestlog1[[2]][-1], "treatment"="nivolumab", "fit"="log-logistic"),
	data.frame("x"=xsim[-1], "y"=bestlog1[[3]][-1], "treatment"="everolimus", "fit"="log-logistic"),
	data.frame("x"=xsim[-1], "y"=bestweib1[[1]][-1], "treatment"="cabozantinib", "fit"="Weibull"),
	data.frame("x"=xsim[-1], "y"=bestweib1[[2]][-1], "treatment"="nivolumab", "fit"="Weibull"),
	data.frame("x"=xsim[-1], "y"=bestweib1[[3]][-1], "treatment"="everolimus", "fit"="Weibull"),
	data.frame("x"=xsim[-1], "y"=bestgomp1[[1]][-1], "treatment"="cabozantinib", "fit"="Gompertz"),
	data.frame("x"=xsim[-1], "y"=bestgomp1[[2]][-1], "treatment"="nivolumab", "fit"="Gompertz"),
	data.frame("x"=xsim[-1], "y"=bestgomp1[[3]][-1], "treatment"="everolimus", "fit"="Gompertz"),
	data.frame("x"=xsim[-1], "y"=bestexp1[[1]][-1], "treatment"="cabozantinib", "fit"="exponential"),
	data.frame("x"=xsim[-1], "y"=bestexp1[[2]][-1], "treatment"="nivolumab", "fit"="exponential"),
	data.frame("x"=xsim[-1], "y"=bestexp1[[3]][-1], "treatment"="everolimus", "fit"="exponential")
	)
ggbest$y <- ggbest$y/2.5

#plot:
	tt5 <- ggplot(data=ggbest[seq(1,nrow(ggbest), length=200),]) + geom_line(aes(x=x, y=y, group=treatment, color=treatment), size=2) + facet_grid(.~fit) + scale_colour_grey() + 
			xlab("time (months)") + ylab("probability of being the best treatment") + 
			xlim(c(0,24)) + ylim(c(0,1)) + scale_x_continuous(breaks=c(6,12,18,24)) + theme_bw(base_size=18) + theme(legend.position="bottom")




#KM curves
	par(mfrow=c(1,2))
	plot(survfit(Surv(os1_cabo$patient[,1],os1_cabo$patient[,2])~1,type="kaplan-meier"), col="blue", lwd=2, xlab="months", ylab="Overall Survival")
	lines(survfit(Surv(os1_ev$patient[,1],os1_ev$patient[,2])~1,type="kaplan-meier"), col="darkgreen", lwd=2)
	plot(survfit(Surv(os2_nivo$patient[,1],os2_nivo$patient[,2])~1,type="kaplan-meier"), col="darkblue", lwd=2, xlab="months", ylab="Overall Survival")
	lines(survfit(Surv(os2_ev$patient[,1],os2_ev$patient[,2])~1,type="kaplan-meier"), col="orange", lwd=2)

##gg plot quality of fit
	sf1 <- survfit(Surv(os1_cabo$patient[,1],os1_cabo$patient[,2])~1,type="kaplan-meier")
	sf2 <- survfit(Surv(os1_ev$patient[,1],os1_ev$patient[,2])~1,type="kaplan-meier")
	sf3 <- survfit(Surv(os2_nivo$patient[,1],os2_nivo$patient[,2])~1,type="kaplan-meier")
	sf4 <- survfit(Surv(os2_ev$patient[,1],os2_ev$patient[,2])~1,type="kaplan-meier")

	ggsf <- rbind(	data.frame("time"=sf1$time, "surv"=sf1$surv, "lower"=sf1$lower, "upper"=sf1$upper, "study"="Choueiri et al", "curve"="cabozantinib (Choueiri et al)"),
					data.frame("time"=sf2$time, "surv"=sf2$surv, "lower"=sf2$lower, "upper"=sf2$upper, "study"="Choueiri et al", "curve"="everolimus (Choueiri et al)"),
					data.frame("time"=sf3$time, "surv"=sf3$surv, "lower"=sf3$lower, "upper"=sf3$upper, "study"="Motzer et al",   "curve"="nivolumab (Motzer et al)"),
					data.frame("time"=sf4$time, "surv"=sf4$surv, "lower"=sf4$lower, "upper"=sf4$upper, "study"="Motzer et al",   "curve"="everolimus (Motzer et al)"))
	ggsf <- ggsf[ggsf$time <= 24,]
	ggsf_log <- ggdata[ggdata$fit=="log-logistic", c("xsim", "med", "l025", "u975", "study", "curve")]
	names(ggsf_log) <- names(ggsf)

	tt6 <- ggplot(data=ggsf_log, aes(x=time)) + geom_line(aes(y=surv), size=1.5) + 
			facet_grid(. ~ curve) + 
			geom_ribbon(aes(ymax=upper, ymin=lower), alpha=.2) + 
			# geom_point(data=ggsf, aes(y=surv)) +
			geom_step(data=ggsf, aes(x=time, y=surv)) +
			geom_step(data=ggsf, aes(x=time, y=upper), lty=2) + 
			geom_step(data=ggsf, aes(x=time, y=lower), lty=2) +
			xlab("time [months]") + ylab("Overall survival") +
			# ggtitle("Fitted survival curves from both studies (no adjustment)") +
			xlim(c(0,24)) + ylim(c(0,1)) + scale_x_continuous(breaks=c(0,6,12,18,24)) + theme_bw(base_size=20)
			# ggsave("outputs\\ggtest1.jpg", tt1, width=12, height=9, dpi=300, quality=90)

	ggsf_all <- ggdata[, c("xsim", "med", "l025", "u975", "study", "curve", "fit")]
	ggsf_4 <- rbind(data.frame(ggsf, "fit"="log-logistic"), data.frame(ggsf, "fit"="Weibull"), data.frame(ggsf, "fit"="Gompertz"), data.frame(ggsf, "fit"="Exponential"))
	names(ggsf_all) <- names(ggsf_4)
	tt6_big <- ggplot(data=ggsf_all, aes(x=time)) + geom_line(aes(y=surv), size=1.5) + 
			facet_grid(fit ~ curve) + 
			geom_ribbon(aes(ymax=upper, ymin=lower), alpha=.2) + 
			geom_step(data=ggsf_4, aes(x=time, y=surv), lwd=1) +
			geom_step(data=ggsf_4, aes(x=time, y=upper), lty=2, lwd=1) + 
			geom_step(data=ggsf_4, aes(x=time, y=lower), lty=2, lwd=1) +
			xlab("time [months]") + ylab("Overall survival") +
			xlim(c(0,24)) + ylim(c(0,1)) + scale_x_continuous(breaks=c(0,6,12,18,24)) + theme_bw(base_size=20)


#ggplot of data (no adjustments, facetted)
	tt1_new <- ggplot(ggdata, aes(x=xsim)) + geom_line(aes(y=med, group=curve, colour=curve), size=1.5) +
			geom_step(data=ggsf, aes(x=time, y=surv, group=curve, color=curve), lwd=1.2) +
			facet_grid(study ~ fit) + 
			geom_ribbon(aes(ymax=u975, ymin=l025, group=curve, fill=curve), alpha=.25) + 
			# geom_ribbon(aes(ymax=u75, ymin=l25, group=curve, fill=curve), alpha=.2) + 
			scale_fill_manual(values=cbPalette) + 
			xlab("Months") + ylab("Overall survival") +
			# geom_point(data=ggpoint, aes(x=time, y=prop, group=original, color=original, shape=original), size=3) +
			ggtitle("Fitted survival curves from both studies (no adjustment)") +
			xlim(c(0,30)) + ylim(c(0,1)) + scale_x_continuous(breaks=c(0,6,12,18,24)) + theme_bw(base_size=16)
			# ggsave("outputs\\ggtest1.jpg", tt1, width=12, height=9, dpi=300, quality=90)



#traditional HR calculation (Bucher):
	varloghr1 <- ((log(0.93)-log(0.73))/2.43)^2 #nivo
	# varloghr1 <- ((log(0.93)-log(0.73))/1.96)^2 #nivo
	varloghr2 <- ((log(0.89)-log(0.67))/1.96)^2 #cabo
	loghr1 <-  log(0.73)
	loghr2 <-  log(0.67)

	varhoghr <- varloghr1 + varloghr2
	loghr <- loghr1-loghr2
	bucher <- c(
	exp(loghr - 1.96*sqrt(varhoghr)),
	exp(loghr),
	exp(loghr + 1.96*sqrt(varhoghr)))